To test this project source code files from various open source projects
are included in this directory.

HexFiend (https://github.com/ridiculousfish/HexFiend)
bottle-sqlalchemy (https://github.com/iurisilvio/bottle-sqlalchemy)
foundation6 (https://foundation.zurb.com/sites/download/)
gumbo-parser (https://github.com/google/gumbo-parser)
jasmine (https://github.com/jasmine/jasmine)
lodepng (https://github.com/lvandeve/lodepng)
lua (https://github.com/lua/lua)
maven (https://github.com/apache/maven)
nginx (https://github.com/nginx/nginx)
polydraw (https://github.com/polydraw/polydraw)
rfmt (https://github.com/google/rfmt)
rustfmt (https://github.com/rust-lang-nursery/rustfmt)
spark (https://spark.apache.org)
xv6 (https://github.com/guilleiguaran/xv6)
